@@ -13,7 +13,7 @@ class Quotenime:
       r = requests.get(base_url)
       result = r.json()
       quote = result['sentence']
-      char = result['characther']
+      char = result['character']
       anime = result['anime']
     else:
       re = requests.get(base_url)
@@ -24,4 +24,4 @@ class Quotenime:
 
     quote = quote or None
     char = char or None
-    anime = anime or None
\ No newline at end of file
+    anime = anime or None
